/*-------------------------------------------------------------------
 *
 *  @file blt_server.h
 *
 *  @author Collin R. Mulliner <collin@mulliner.org>
 *
 *  (c) Collin R. Mulliner
 *
 *  This is part of the Bluetooth Location Tracker (BLT) project.
 *
 *-------------------------------------------------------------------*/

/*
 * This file is part of blt_server
 *
 * blt_server is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * blt_server is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with blt_server; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */
 
#define _GNU_SOURCE
#include <time.h>
#include <pthread.h>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/socket.h>
#include <netinet/in.h>
#include <netdb.h>
#include <string.h>
#include <signal.h>
#include <assert.h>
#include <openssl/ssl.h>
#include <openssl/rand.h>

#include "util.h"
#include "push.h"
#include "blt.h"
#include "location.h"

#define DN_HASH 1
/* #define DN_TREE 1 */
#include "names.h"

#include "tracker.h"
#include "server.h"
#include "data.h"

#ifndef __BLT_SERVER_H__
#define __BTL_SERVER_H__


#define DEBUG
#define DEBUG2
#define DEBUG3
#define DEBUG4
#define DEBUG5


#define BLT_SERVER_BANNER "Bluetooth Location Tracker Server v0.1.4 (c) 2003 the BLT Project Team (this is free software!)\n"

#define CERT_FILEPATH "cert.pem"

struct mcp_t {
	pthread_t tc_serv;
	pthread_t dc_serv;
	pthread_t push_serv;
	
	struct blt_server_session_t server;
		
	time_t curInq;
	time_t lastInq;
	int inqStep;		/**< seconds between inquirys */
	int wakeupDelay;	/**< seconds between wakeups */
	
	int running;		/**< mcp running? */
};

#endif
