/*-------------------------------------------------------------------
 *
 *  @file names.h
 *
 *  @author Collin R. Mulliner <collin@mulliner.org>
 *
 *  (c) Collin R. Mulliner
 *
 *  This is part of the Bluetooth Location Tracker (BLT) project.
 *
 *-------------------------------------------------------------------*/

/*
 * This file is part of blt_server
 *
 * blt_server is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * blt_server is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with blt_server; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */
 
#ifndef __NAMES_H__
#define __NAMES_H__

#define BLT_DEVICE_NAMES_FILE "blt_device_names.dn"

#define DN_HASHTABLE_SIZE 4093
/* prims: 1021, 2039, 4093, 8191, 16381, 32749, 65521, 131071 */

#ifdef DN_TREE
struct tnode_t {
	struct tnode_t *l;			/**< smaller node */
	struct tnode_t *r;			/**< bigger node */
	struct blt_device_t dev;	/**< device data */
};
#endif

struct blt_dev_names_t {

	#ifdef DN_HASH
	struct blt_device_t *devices;		/**< device store */
	unsigned int maxNumDevices;		/**< store size */
	#endif
	
	#ifdef DN_TREE
	struct tnode_t *devices;	/**< device store */
	#endif
	
	unsigned int numDevices;	/**< number of devices */
	pthread_rwlock_t lock;		/**< store lock */
};

#endif

int blt_dn_write(struct blt_dev_names_t *dn, struct blt_device_t *nDev);
int blt_dn_read(struct blt_dev_names_t *dn, struct blt_device_t *nDev);
void blt_dn_init(struct blt_dev_names_t *dn);
void blt_dn_destroy(struct blt_dev_names_t *dn);
int blt_dn_load(struct blt_dev_names_t *dn);
int blt_dn_save(struct blt_dev_names_t *dn);
